unit Unit1;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls,
  fpvutils,   // for RGBToFPColor()
  fpvectorialpkg, fpvectorial;

type
  { TForm1 }
  TForm1 = class(TForm)
    Button1: TButton;
    procedure Button1Click(Sender: TObject);
  private

  public

  end;

type
  { TvTableHelper }
  TvTableHelper = class helper for TvTable
  public
    function AddColWidth(AValue: Double): Integer;
  end;

var
  Form1: TForm1;

implementation

{$R *.lfm}

{ TvTableHelper }

function TvTableHelper.AddColWidth(AValue: Double): Integer;
begin
  SetLength(ColWidths, Length(ColWidths) + 1);
  ColWidths[High(ColWidths)] := AValue;
  Result := 0;
end;

{ TForm1 }

procedure TForm1.Button1Click(Sender: TObject);
var
  Document: TvVectorialDocument;
  Page: TvTextPageSequence;
  BoldTextStyle: TvStyle;
  HeaderParagraph, Paragraph: TvParagraph;
  DaysTable: TvTable;
  Row: TvTableRow;
  Cell: TvTableCell;
  intRow, intCol, intTotalRows: integer;
  DaysArray, HoursWorkedArray: array of string;
begin
  //
  DaysArray := ['DAYS', 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
  HoursWorkedArray := ['HOURS WORKED', '4 ', '7 ', '8 ', '8 ', '4 ', '8 ', '0 '];   // Spaces after numbers necessary otherwise
                                                                                    // Paragraph.AddText(HoursWorkedArray[intRow]) below
                                                                                    // will print empty strings

  // Create the document
  Document := TvVectorialDocument.Create;

  //
  try
     //  Adds the defaut Paragraph Styles
    //    StyleTextBody, StyleHeading1,
    //    StyleHeading2 & StyleHeading3
    Document.AddStandardTextDocumentStyles(vfUnknown);

    // Add our own Style
    BoldTextStyle             := Document.AddStyle();
    BoldTextStyle.Kind        := vskTextSpan;
    BoldTextStyle.Name        := 'Bold';
    BoldTextStyle.Font.Bold   := True;
    BoldTextStyle.SetElements := BoldTextStyle.SetElements + [spbfFontBold];

    // Add a page and a paragraph
    Page                      := Document.AddTextPageSequence;
    //
    HeaderParagraph           := Page.AddParagraph;
    HeaderParagraph.Style     := Document.StyleHeading1Centralized;
    HeaderParagraph.AddText('WORK SCHEDULE');
    HeaderParagraph           := Page.AddParagraph;

    // Add the Days table
    DaysTable                  := Page.AddTable;
    DaysTable.PreferredWidth   := Dimension(100, dimPercent);
    DaysTable.ColWidthsUnits   := dimMillimeter;
    // Add 2 columns
    DaysTable.AddColWidth(50);
    DaysTable.AddColWidth(50);

    // Get the number of rows to add to the table
    intTotalRows := Length(DaysArray);
    //
    for intRow := 0 to Pred(intTotalRows) do
    begin
      Row                            := DaysTable.AddRow;
      if intRow = 0 then
      begin
        Row.BackgroundColor := RGBToFPColor(192, 192, 192); // Grey Shading
        Row.Header := True; // Tell the table this is a Header Row
      end;

      // Add 1 cells to each Row
      for intCol := 0 to 1 do
      begin
        Cell                           := Row.AddCell;
        Paragraph                      := Cell.AddParagraph;
        Paragraph.Style                := Document.StyleTextBody;
        //
        if intCol = 0 then
          Paragraph.AddText(DaysArray[intRow]).Style := BoldTextStyle
        else
        begin
          if intRow = 0 then
            Paragraph.AddText(HoursWorkedArray[intRow])
          else
            Paragraph.AddText(HoursWorkedArray[intRow]);
        end;
      end;
    end;

    try
      // Save the document
      Document.WriteToFile('Work schedule.docx', vfDOCX);
    except
      raise;
    end;
  finally
    Document.Free;
  end;
end;

end.

